@@ -9,13 +9,12 @@ import traceback
 import torch
 from torch.utils.data import DataLoader
 
-from TTS.speaker_encoder.dataset import MyDataset
-from TTS.speaker_encoder.losses import AngleProtoLoss, GE2ELoss
-from TTS.speaker_encoder.model import SpeakerEncoder
-from TTS.speaker_encoder.utils.io import save_best_model, save_checkpoint
+from TTS.speaker_encoder.dataset import SpeakerEncoderDataset
+from TTS.speaker_encoder.losses import AngleProtoLoss, GE2ELoss, SoftmaxAngleProtoLoss
+from TTS.speaker_encoder.utils.generic_utils import save_best_model, setup_model
 from TTS.speaker_encoder.utils.visual import plot_embeddings
-from TTS.tts.datasets.preprocess import load_meta_data
-from TTS.utils.arguments import init_training
+from TTS.trainer import init_training
+from TTS.tts.datasets import load_meta_data
 from TTS.utils.audio import AudioProcessor
 from TTS.utils.generic_utils import count_parameters, remove_experiment_folder, set_init_dict
 from TTS.utils.radam import RAdam
@@ -34,18 +33,19 @@ def setup_loader(ap: AudioProcessor, is_val: bool = False, verbose: bool = False
     if is_val:
         loader = None
     else:
-        dataset = MyDataset(
+        dataset = SpeakerEncoderDataset(
             ap,
             meta_data_eval if is_val else meta_data_train,
-            voice_len=1.6,
+            voice_len=c.voice_len,
             num_utter_per_speaker=c.num_utters_per_speaker,
             num_speakers_in_batch=c.num_speakers_in_batch,
-            skip_speakers=False,
+            skip_speakers=c.skip_speakers,
             storage_size=c.storage["storage_size"],
             sample_from_storage_p=c.storage["sample_from_storage_p"],
-            additive_noise=c.storage["additive_noise"],
             verbose=verbose,
+            augmentation_config=c.audio_augmentation,
         )
+
         # sampler = DistributedSampler(dataset) if num_gpus > 1 else None
         loader = DataLoader(
             dataset,
@@ -54,22 +54,23 @@ def setup_loader(ap: AudioProcessor, is_val: bool = False, verbose: bool = False
             num_workers=c.num_loader_workers,
             collate_fn=dataset.collate_fn,
         )
-    return loader
+    return loader, dataset.get_num_speakers()
 
 
-def train(model, criterion, optimizer, scheduler, ap, global_step):
-    data_loader = setup_loader(ap, is_val=False, verbose=True)
+def train(model, optimizer, scheduler, criterion, data_loader, global_step):
     model.train()
     epoch_time = 0
     best_loss = float("inf")
     avg_loss = 0
+    avg_loss_all = 0
     avg_loader_time = 0
     end_time = time.time()
+
     for _, data in enumerate(data_loader):
         start_time = time.time()
 
         # setup input data
-        inputs = data[0]
+        inputs, labels = data
         loader_time = time.time() - end_time
         global_step += 1
 
@@ -81,13 +82,13 @@ def train(model, criterion, optimizer, scheduler, ap, global_step):
         # dispatch data to GPU
         if use_cuda:
             inputs = inputs.cuda(non_blocking=True)
-            # labels = labels.cuda(non_blocking=True)
+            labels = labels.cuda(non_blocking=True)
 
         # forward pass model
         outputs = model(inputs)
 
         # loss computation
-        loss = criterion(outputs.view(c.num_speakers_in_batch, outputs.shape[0] // c.num_speakers_in_batch, -1))
+        loss = criterion(outputs.view(c.num_speakers_in_batch, outputs.shape[0] // c.num_speakers_in_batch, -1), labels)
         loss.backward()
         grad_norm, _ = check_update(model, c.grad_clip)
         optimizer.step()
@@ -129,16 +130,17 @@ def train(model, criterion, optimizer, scheduler, ap, global_step):
                 ),
                 flush=True,
             )
+        avg_loss_all += avg_loss
 
-        # save best model
-        best_loss = save_best_model(model, optimizer, avg_loss, best_loss, OUT_PATH, global_step)
-        end_time = time.time()
-
-        # checkpoint and check stop train cond.
         if global_step >= c.max_train_step or global_step % c.save_step == 0:
-            save_checkpoint(model, optimizer, avg_loss, OUT_PATH, global_step)
+            # save best model only
+            best_loss = save_best_model(model, optimizer, criterion, avg_loss, best_loss, OUT_PATH, global_step)
+            avg_loss_all = 0
             if global_step >= c.max_train_step:
                 break
+
+        end_time = time.time()
+
     return avg_loss, global_step
 
 
@@ -147,19 +149,22 @@ def main(args):  # pylint: disable=redefined-outer-name
     global meta_data_train
     global meta_data_eval
 
-    ap = AudioProcessor(**c.audio.to_dict())
-    model = SpeakerEncoder(
-        input_dim=c.model_params["input_dim"],
-        proj_dim=c.model_params["proj_dim"],
-        lstm_dim=c.model_params["lstm_dim"],
-        num_lstm_layers=c.model_params["num_lstm_layers"],
-    )
+    ap = AudioProcessor(**c.audio)
+    model = setup_model(c)
+
     optimizer = RAdam(model.parameters(), lr=c.lr)
 
+    # pylint: disable=redefined-outer-name
+    meta_data_train, meta_data_eval = load_meta_data(c.datasets, eval_split=False)
+
+    data_loader, num_speakers = setup_loader(ap, is_val=False, verbose=True)
+
     if c.loss == "ge2e":
         criterion = GE2ELoss(loss_method="softmax")
     elif c.loss == "angleproto":
         criterion = AngleProtoLoss()
+    elif c.loss == "softmaxproto":
+        criterion = SoftmaxAngleProtoLoss(c.model["proj_dim"], num_speakers)
     else:
         raise Exception("The %s  not is a loss supported" % c.loss)
 
@@ -167,23 +172,24 @@ def main(args):  # pylint: disable=redefined-outer-name
         checkpoint = torch.load(args.restore_path)
         try:
             model.load_state_dict(checkpoint["model"])
-        except KeyError:
+
+            if "criterion" in checkpoint:
+                criterion.load_state_dict(checkpoint["criterion"])
+
+        except (KeyError, RuntimeError):
             print(" > Partial model initialization.")
             model_dict = model.state_dict()
-            model_dict = set_init_dict(model_dict, checkpoint, c)
+            model_dict = set_init_dict(model_dict, checkpoint["model"], c)
             model.load_state_dict(model_dict)
             del model_dict
         for group in optimizer.param_groups:
             group["lr"] = c.lr
+
         print(" > Model restored from step %d" % checkpoint["step"], flush=True)
         args.restore_step = checkpoint["step"]
     else:
         args.restore_step = 0
 
-    if use_cuda:
-        model = model.cuda()
-        criterion.cuda()
-
     if c.lr_decay:
         scheduler = NoamLR(optimizer, warmup_steps=c.warmup_steps, last_epoch=args.restore_step - 1)
     else:
@@ -192,11 +198,12 @@ def main(args):  # pylint: disable=redefined-outer-name
     num_params = count_parameters(model)
     print("\n > Model has {} parameters".format(num_params), flush=True)
 
-    # pylint: disable=redefined-outer-name
-    meta_data_train, meta_data_eval = load_meta_data(c.datasets)
+    if use_cuda:
+        model = model.cuda()
+        criterion.cuda()
 
     global_step = args.restore_step
-    _, global_step = train(model, criterion, optimizer, scheduler, ap, global_step)
+    _, global_step = train(model, optimizer, scheduler, criterion, data_loader, global_step)
 
 
 if __name__ == "__main__":
