@@ -8,10 +8,21 @@ import shutil
 import subprocess
 import sys
 from pathlib import Path
+from typing import Dict
 
 import torch
 
 
+def to_cuda(x: torch.Tensor) -> torch.Tensor:
+    if x is None:
+        return None
+    if torch.is_tensor(x):
+        x = x.contiguous()
+        if torch.cuda.is_available():
+            x = x.cuda(non_blocking=True)
+    return x
+
+
 def get_cuda():
     use_cuda = torch.cuda.is_available()
     device = torch.device("cuda:0" if torch.cuda.is_available() else "cpu")
@@ -47,13 +58,10 @@ def get_commit_hash():
     return commit
 
 
-def create_experiment_folder(root_path, model_name, debug):
+def create_experiment_folder(root_path, model_name):
     """Create a folder with the current date and time"""
     date_str = datetime.datetime.now().strftime("%B-%d-%Y_%I+%M%p")
-    if debug:
-        commit_hash = "debug"
-    else:
-        commit_hash = get_commit_hash()
+    commit_hash = get_commit_hash()
     output_folder = os.path.join(root_path, model_name + "-" + date_str + "-" + commit_hash)
     os.makedirs(output_folder, exist_ok=True)
     print(" > Experiment folder: {}".format(output_folder))
@@ -126,6 +134,22 @@ def set_init_dict(model_dict, checkpoint_state, c):
     return model_dict
 
 
+def format_aux_input(def_args: Dict, kwargs: Dict) -> Dict:
+    """Format kwargs to hande auxilary inputs to models.
+
+    Args:
+        def_args (Dict): A dictionary of argument names and their default values if not defined in `kwargs`.
+        kwargs (Dict): A `dict` or `kwargs` that includes auxilary inputs to the model.
+
+    Returns:
+        Dict: arguments with formatted auxilary inputs.
+    """
+    for name in def_args:
+        if name not in kwargs:
+            kwargs[def_args[name]] = None
+    return kwargs
+
+
 class KeepAverage:
     def __init__(self):
         self.avg_values = {}
